summaryrefslogtreecommitdiffstats
path: root/src/WorldStorage/NBTChunkSerializer.h
diff options
context:
space:
mode:
authorLogicParrot <LogicParrot@users.noreply.github.com>2017-08-27 08:13:40 +0200
committerLogicParrot <LogicParrot@users.noreply.github.com>2017-08-27 08:13:40 +0200
commite274d0dd8a6eefeb6e84272ffd09ac55b2c08900 (patch)
tree377f52ed5738810c157e631ec31f626fbe5acef6 /src/WorldStorage/NBTChunkSerializer.h
parentd (diff)
parentImplement anvil chunk sparsing (diff)
downloadcuberite-e274d0dd8a6eefeb6e84272ffd09ac55b2c08900.tar
cuberite-e274d0dd8a6eefeb6e84272ffd09ac55b2c08900.tar.gz
cuberite-e274d0dd8a6eefeb6e84272ffd09ac55b2c08900.tar.bz2
cuberite-e274d0dd8a6eefeb6e84272ffd09ac55b2c08900.tar.lz
cuberite-e274d0dd8a6eefeb6e84272ffd09ac55b2c08900.tar.xz
cuberite-e274d0dd8a6eefeb6e84272ffd09ac55b2c08900.tar.zst
cuberite-e274d0dd8a6eefeb6e84272ffd09ac55b2c08900.zip
Diffstat (limited to 'src/WorldStorage/NBTChunkSerializer.h')
-rw-r--r--src/WorldStorage/NBTChunkSerializer.h13
1 files changed, 5 insertions, 8 deletions
diff --git a/src/WorldStorage/NBTChunkSerializer.h b/src/WorldStorage/NBTChunkSerializer.h
index 3637ea655..50d98a518 100644
--- a/src/WorldStorage/NBTChunkSerializer.h
+++ b/src/WorldStorage/NBTChunkSerializer.h
@@ -1,4 +1,4 @@
-
+
// NBTChunkSerializer.h
// Declares the cNBTChunkSerializer class that is used for saving individual chunks into NBT format used by Anvil
@@ -55,7 +55,7 @@ class cPainting;
class cNBTChunkSerializer :
- public cChunkDataSeparateCollector
+ public cChunkDataCopyCollector
{
public:
cChunkDef::BiomeMap m_Biomes;
@@ -69,15 +69,12 @@ public:
/** Close NBT tags that we've opened */
void Finish(void);
- bool IsLightValid(void) const {return m_IsLightValid; }
+ bool IsLightValid(void) const { return m_IsLightValid; }
protected:
- /* From cChunkDataSeparateCollector we inherit:
- - m_BlockTypes[]
- - m_BlockMetas[]
- - m_BlockLight[]
- - m_BlockSkyLight[] */
+ /* From cChunkDataCopyCollector we inherit:
+ - cChunkData m_Data */
cFastNBTWriter & m_Writer;